@@ -17,7 +17,7 @@ use Class::Accessor::Lite (
     ro  => [ qw(conf dbh) ],
 );
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 sub load {
     my $v = Data::Validator->new(
@@ -51,20 +51,27 @@ sub load_all {
 
 sub create {
     my $v = Data::Validator->new(
-        tables => +{ isa => 'ArrayRef[Str]' }
+        tables    => +{ isa => 'ArrayRef[Str]' },
+        create_file => +{ isa => 'Bool', default => 1 },
     )->with(qw/Method  StrictSequenced/);
     my($self, $args) = $v->validate(@_);
 
+    my @result;
     for my $data ($self->_build_create_data($args->{tables})) {
-        $self->_make_fixture_yaml($data);
+        push @result, [$self->_make_fixture_yaml(+{%$data, create_file => $args->{create_file}})];
     }
+
+    return @result;
 }
 
 sub create_all {
-    my ($self,) = @_;
+    my $v = Data::Validator->new(
+        create_file => +{ isa => 'Bool', default => 1 },
+    )->with(qw/Method/);
+    my($self, $args) = $v->validate(@_);
 
     my @tables = map { $_->[2] } @{$self->dbh->table_info('','','')->fetchall_arrayref};
-    $self->create(\@tables);
+    $self->create(\@tables, $args->{create_file});
 }
 
 sub ignore_tables {
@@ -140,11 +147,7 @@ sub _build_create_data {
     my @tables = $self->_difference_ignore_tables($args->{tables});
     return unless scalar @tables;
 
-    my $schema = Teng::Schema::Loader->load(
-        dbh => $self->dbh,
-        namespace => 'Hoge',
-    )->schema;
-
+    my $schema = $self->_load_schema($self->dbh);
     my @shema_tables = keys %{$schema->{tables}};
 
     my $sql_maker = SQL::Maker->new(driver => $self->conf->{driver});
@@ -164,11 +167,23 @@ sub _build_create_data {
     return @data;
 }
 
+sub _load_schema {
+    my ($self, $dbh) = @_;
+
+    $self->{__schema} = Teng::Schema::Loader->load(
+        dbh => $dbh,
+        namespace => 'Hoge',
+    )->schema unless $self->{__schema};
+
+    return $self->{__schema};
+}
+
 sub _make_fixture_yaml {
     my $v = Data::Validator->new(
-        table   => 'Str',
-        columns => 'ArrayRef[Str]',
-        sql     => 'Str',
+        table     => 'Str',
+        columns   => 'ArrayRef[Str]',
+        sql       => 'Str',
+        create_file => +{ isa => 'Bool', default => 1 },
     )->with(qw/Method/);
     my($self, $args) = $v->validate(@_);
 
@@ -180,7 +195,7 @@ sub _make_fixture_yaml {
         $tmp_args{table},
         $tmp_args{columns},
         $tmp_args{sql},
-        $fixture_path,
+        $args->{create_file} ? $fixture_path : (),
     );
 }
 
